// USB_Storage.scad by MegaSaturnv

/////////////////////////////
// Customizable Parameters //
/////////////////////////////
/* [Basic] */
//Thickness of the perimeter. Distance between the outer USB ports and the edge
BOX_PERIMETER = 1.2;
//Thickness of the box base. Distance beween the bottom of the USB ports and the bottom of the box
LOWER_BOX_HEIGHT = 1;

//Amount of USB ports along the X axis
QUANTITY_X = 3;
//Amount of USB ports along the Y axis
QUANTITY_Y = 10;

//Extra width given to USB devices. It is the half the gap between ports along the X axis
USB_WIDTH_GAP_PERIMETER = 7;
//Extra length given to USB devices. It is the half the gap between ports along the Y axis
USB_LENGTH_GAP_PERIMETER = 4;

/* [Advanced] */
USB_WIDTH_LOWER = 12.1;
USB_WIDTH_UPPER = 12.8;
USB_LENGTH_LOWER = 4.1;
USB_LENGTH_UPPER = 5.2;
USB_HEIGHT = 13;

//Use $fn = 24 if it's a preview. $fn = 96 for the render. Increase 96 to produce a smoother curve.
$fn = $preview ? 24 : 96;


/////////////
// Modules //
/////////////
module taperedHole(widthLower, widthUpper, lengthLower, lengthUpper, height) {
	CubePoints = [
		[ (widthUpper-widthLower)/2, (lengthUpper-lengthLower)/2,                            0 ], //0
		[ widthLower + (widthUpper-widthLower)/2, (lengthUpper-lengthLower)/2,               0 ], //1
		[ widthLower + (widthUpper-widthLower)/2, lengthLower + (lengthUpper-lengthLower)/2, 0 ], //2
		[ (widthUpper-widthLower)/2,              lengthLower + (lengthUpper-lengthLower)/2, 0 ], //3
		[ 0,          0,           height ],  //4
		[ widthUpper, 0,           height ],  //5
		[ widthUpper, lengthUpper, height ],  //6
		[ 0,          lengthUpper, height ]]; //7
  
	CubeFaces = [
		[0,1,2,3],  // bottom
		[4,5,1,0],  // front
		[7,6,5,4],  // top
		[5,6,2,1],  // right
		[6,7,3,2],  // back
		[7,4,0,3]]; // left

	polyhedron( CubePoints, CubeFaces );
}

module storageBox(itemWidthLower, itemWidthUpper, itemLengthLower, itemLengthUpper, itemHeight, itemPerimeterWidth, itemPerimeterLength, boxBaseHeight, QtyX, QtyY) {
	difference() {
		cube([(QtyX-1) * (itemWidthUpper + 2*itemPerimeterWidth) + itemWidthUpper + 2*BOX_PERIMETER, (QtyY-1) * (itemLengthUpper + 2*itemPerimeterLength) + itemLengthUpper + 2*BOX_PERIMETER, itemHeight + boxBaseHeight]);

		for (i = [0 : QtyX-1], j = [0 : QtyY-1]) {				
				translate([BOX_PERIMETER + i * (itemWidthUpper + 2*itemPerimeterWidth), BOX_PERIMETER + j * (itemLengthUpper + 2*itemPerimeterLength), boxBaseHeight + 0.01]) taperedHole(itemWidthLower, itemWidthUpper, itemLengthLower, itemLengthUpper, itemHeight);
		}
    }
}


////////////////
// Main Model //
////////////////
storageBox(USB_WIDTH_LOWER, USB_WIDTH_UPPER, USB_LENGTH_LOWER, USB_LENGTH_UPPER, USB_HEIGHT, USB_WIDTH_GAP_PERIMETER, USB_LENGTH_GAP_PERIMETER, LOWER_BOX_HEIGHT, QUANTITY_X, QUANTITY_Y);